﻿// Sketchables.NET - Design Time Support Libraries
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Gnu General Public License (GPL) v3
// Please see http://www.gnu.org/licenses/gpl.html for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System;
using System.Windows.Controls;
using System.Windows.Input;

namespace Sketchables.Design.ContentEditor
{
  /// <summary>
  /// Interaction logic for SketchableEditor.xaml
  /// </summary>
  public partial class SketchableEditor
  {
    public event Action CommitChanges;

    
    public string EditorText
    {
      get { return Input.Text; }
      set { Input.Text = value; }
    }

    public void FocusEditor()
    {
      Keyboard.Focus(Input);
      Input.SelectAll();
    }

    public SketchableEditor()
    {
      InitializeComponent();
    }



    /// <summary>
    /// Raises the <see cref="CommitChanges"/> event if the user either
    /// presses ESC or enter in case of single line editing.
    /// </summary>
    private void Input_KeyDown(object sender, KeyEventArgs e)
    {
      if(e.Key == Key.Escape ||
        !Input.AcceptsReturn && (e.Key == Key.Enter || e.Key == Key.Return))
      {
        CommitChanges();
      }
    }

    


  }
}
