﻿// Sketchables.NET - Design Time Support Libraries
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Gnu General Public License (GPL) v3
// Please see http://www.gnu.org/licenses/gpl.html for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Windows.Design.Metadata;
using Microsoft.Windows.Design.Model;
using Sketchables.Design.Markup;

namespace Sketchables.Design
{
  /// <summary>
  /// Helper class which is used to resolve either Silverlight or
  /// WPF types.
  /// </summary>
  internal abstract class SketchableTypeFactory
  {
    /// <summary>
    /// Takes a platform neutral TypeIdentifier
    /// and returns back a platform specific Type.
    /// For each of the types you are providing a design experience for,
    /// you must add an entry to this method.
    /// </summary>
    public Type GetPlatformType(TypeIdentifier id)
    {
      return GetSupportedTypes().FirstOrDefault(t => t.FullName == id.Name);
    }


    /// <summary>
    /// Returns the platform-specific type defined by the underlying enum.
    /// </summary>
    /// <returns></returns>
    public abstract Type GetPlatformType(SketchablePlatformTypes platformType);


    /// <summary>
    /// Gets a type converter which can handle sketching markup for the
    /// submitted model item.
    /// </summary>
    /// <returns></returns>
    public abstract ISketchingMarkupConverter GetConverter(ModelItem modelItem);


    /// <summary>
    /// Resolves all types that are supported by the library.
    /// </summary>
    /// <returns></returns>
    protected abstract IEnumerable<Type> GetSupportedTypes();
  }

}
