﻿// Sketchables.NET - Design Time Support Libraries
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Gnu General Public License (GPL) v3
// Please see http://www.gnu.org/licenses/gpl.html for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE



using System;
using Microsoft.Windows.Design.Model;

namespace Sketchables.Design.Markup.Converters
{
  public abstract class ItemInfo
  {
    /// <summary>
    /// The index of the item within the list.
    /// </summary>
    public int Index { get; set; }

    /// <summary>
    /// The designer model for the tab.
    /// </summary>
    public ModelItem Model { get; set; }

    /// <summary>
    /// Flag used to indicate that the tab is reused (reassigned to its
    /// parent). This makes sure that if a parent control contains several
    /// tabs with equal headers, we don't mix them up.
    /// </summary>
    public bool IsUsed { get; set; }

    /// <summary>
    /// Provides case-insensitive comparison. This might lead to issues in case
    /// of rearranged tabs with equal headers, but so what - it's well worth the
    /// simplification of being able to just correct case-related typos.
    /// </summary>
    /// <param name="other"></param>
    /// <returns></returns>
    public virtual bool Matches(SketchItem other)
    {
      string headerValue = other.ContentMarkup.Trim();
      string id = (Identifier ?? "").Trim();
      return id.Equals(headerValue, StringComparison.InvariantCultureIgnoreCase);
    }


    /// <summary>
    /// Gets an identifier that can be used to compare the represented modelitem
    /// to a <see cref="SketchItem"/> instance in the <see cref="Matches"/> method.
    /// </summary>
    protected abstract string Identifier { get; }
  }
}
