﻿// Sketchables.NET - Design Time Support Libraries
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Gnu General Public License (GPL) v3
// Please see http://www.gnu.org/licenses/gpl.html for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System.Collections.Generic;
using System.Linq;
using System.Windows.Controls;
using Microsoft.Windows.Design.Model;

namespace Sketchables.Design.Markup.Converters
{
  public abstract class ListBoxMarkupConverter : ItemsControlConverter<ListBox, ContentControlInfo>
  {

    /// <summary>
    /// Customization that switches on multiple selections if configured accordingly
    /// in markup.
    /// </summary>
    protected override void CustomizeParentItem(ModelItem parentModel, ModelItemCollection itemsCollection, IEnumerable<SketchItem> sketchItems)
    {
      //allow multiple selections if configured accordingly
      if (sketchItems.Count(i => i.IsSelected()) > 1)
      {
        parentModel.SetPropertyValue<ListBox>(l => l.SelectionMode, SelectionMode.Multiple.ToString());
      }
    }

    /// <summary>
    /// Returns the name of the property that is used to
    /// identify the item. This is also the identifier that
    /// is being used to produce sketching markup.
    /// </summary>
    protected override string GetItemValueProperty()
    {
      return Extensions.GetPropertyName<ListBoxItem>(i => i.Content);
    }

    /// <summary>
    /// Gets the name of the property that indicates whether
    /// the item is enabled or not.
    /// </summary>
    protected override string GetIsEnabledPropertyName()
    {
      return Extensions.GetPropertyName<ListBoxItem>(i => i.IsEnabled);
    }

    /// <summary>
    /// Gets an item that represents a tab's default content. This item will
    /// be assigned to it's <c>Content</c> property.
    /// </summary>
    /// <returns>Tab content model item.</returns>
    protected override void CustomizeItemDefaults(ModelItem item)
    {
      //we're good
    }

    /// <summary>
    /// Generates a resource string for the 
    /// </summary>
    /// <returns></returns>
    protected override string GetItemStyleName()
    {
      return SketchStyleNames.ListBoxItem;
    }


  }
}
