﻿// Sketchables.NET - Design Time Support Libraries
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Gnu General Public License (GPL) v3
// Please see http://www.gnu.org/licenses/gpl.html for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System.Windows.Controls;
using Microsoft.Windows.Design.Model;

namespace Sketchables.Design.Markup.Converters
{
  /// <summary>
  /// A converter for tab controls. 
  /// </summary>
  public abstract class TabControlMarkupConverter : ItemsControlConverter<TabControl, HeaderedContentControlInfo>
  {
    /// <summary>
    /// Returns the name of the property that is used to
    /// identify the item. This is also the identifier that
    /// is being used to produce sketching markup.
    /// </summary>
    protected override string GetItemValueProperty()
    {
      return Extensions.GetPropertyName<TabItem>(ti => ti.Header);
    }

    /// <summary>
    /// Gets the name of the property that indicates whether
    /// the item is enabled or not.
    /// </summary>
    protected override string GetIsEnabledPropertyName()
    {
      return Extensions.GetPropertyName<TabItem>(ti => ti.IsEnabled);
    }

    /// <summary>
    /// Gets an item that represents a tab's default content. This item will
    /// be assigned to it's <c>Content</c> property.
    /// </summary>
    /// <returns>Tab content model item.</returns>
    protected override void CustomizeItemDefaults(ModelItem item)
    {
      ModelItem contentItem = GetTabContentItem(item);
      item.SetPropertyValue<TabItem>(i => i.Content, contentItem);
    }

    /// <summary>
    /// Creates the default content for the tab.
    /// </summary>
    protected abstract ModelItem GetTabContentItem(ModelItem tabItem);


    /// <summary>
    /// Generates a resource string for the 
    /// </summary>
    /// <returns></returns>
    protected override string GetItemStyleName()
    {
      return SketchStyleNames.TabItem;
    }

  }
}
