﻿// Sketchables.NET - Design Time Support Libraries
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Gnu General Public License (GPL) v3
// Please see http://www.gnu.org/licenses/gpl.html for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using Microsoft.Windows.Design.Model;

namespace Sketchables.Design.Markup
{
  /// <summary>
  /// Provides conversion routines in order to represent a given
  /// sketched item in markup, and update an item base on user inputted
  /// markup.
  /// </summary>
  internal interface ISketchingMarkupConverter
  {
    /// <summary>
    /// Gets sketching markup that is being displayed to the user.
    /// </summary>
    /// <param name="sketchedItem">The processed sketching object. This
    /// <see cref="ModelItem"/> represents either a framework type or
    /// a supported external type.</param>
    /// <returns>Sketching markup that represents the item.</returns>
    string GetMarkup(ModelItem sketchedItem);


    /// <summary>
    /// Updates the underlying object with updated markup.
    /// </summary>
    /// <param name="sketchedItem">The processed sketching object. This
    /// <see cref="ModelItem"/> represents either a framework type or
    /// a supported external type.</param>
    /// <param name="newMarkup">The updated markup which should be applied.</param>
    void UpdateSketchObject(ModelItem sketchedItem, string newMarkup);    
  }
}
