﻿// Sketchables.NET - Design Time Support Libraries
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Gnu General Public License (GPL) v3
// Please see http://www.gnu.org/licenses/gpl.html for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE



using Microsoft.Windows.Design.Model;

namespace Sketchables.Design.Markup
{
  /// <summary>
  /// Base class which just returns / assigns sketching markup for a given
  /// <see cref="ModelItem"/> property.
  /// </summary>
  internal abstract class PropertySketchingMarkupConverter : ISketchingMarkupConverter
  {
    /// <summary>
    /// The <see cref="ModelItem"/> property that provides sketching markup.
    /// </summary>
    public string MarkupPropertyName { get; private set; }


    /// <summary>
    /// Inits the converter with the name of the property that provides
    /// or receives the processed markup.
    /// </summary>
    protected PropertySketchingMarkupConverter(string markupPropertyName)
    {
      MarkupPropertyName = markupPropertyName;
    }


    /// <summary>
    /// Gets sketching markup that is being displayed to the user.
    /// </summary>
    /// <param name="sketchedItem">The processed sketching object. This
    /// <see cref="ModelItem"/> represents either a framework type or
    /// a supported external type.</param>
    /// <returns>Sketching markup that represents the item.</returns>
    public string GetMarkup(ModelItem sketchedItem)
    {
      return (string)sketchedItem.Properties[MarkupPropertyName].ComputedValue;
    }


    /// <summary>
    /// Updates the underlying object with updated markup.
    /// </summary>
    /// <param name="sketchedItem">The processed sketching object. This
    /// <see cref="ModelItem"/> represents either a framework type or
    /// a supported external type.</param>
    /// <param name="newMarkup">The updated markup which should be applied.</param>
    public void UpdateSketchObject(ModelItem sketchedItem, string newMarkup)
    {
      ModelProperty property = sketchedItem.Properties[MarkupPropertyName];
      property.SetValue(newMarkup);
    }
  }
}