﻿// Sketchables.NET - Design Time Support Libraries
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Gnu General Public License (GPL) v3
// Please see http://www.gnu.org/licenses/gpl.html for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System;
using System.Collections.Generic;
using Microsoft.Windows.Design.Model;
using Sketchables.Design;
using Sketchables.Design.Markup;
using Sketchables.Silverlight.Design.Types;

namespace Sketchables.Silverlight.Design
{
  internal class SilverlightTypeFactory : SketchableTypeFactory
  {
    /// <summary>
    /// Returns the platform-specific type defined by the underlying enum.
    /// </summary>
    /// <returns></returns>
    public override Type GetPlatformType(SketchablePlatformTypes platformType)
    {
      switch(platformType)
      {
        case SketchablePlatformTypes.SketchableControl:
          return SilverlightTypes.SketchableControlType;
        case SketchablePlatformTypes.TabControl:
					return SilverlightTypes.TabControlType;
				case SketchablePlatformTypes.SketchableTabControl:
					return SilverlightTypes.SketchableTabControlType;
        case SketchablePlatformTypes.ListBox:
					return SilverlightTypes.ListBoxType;
				case SketchablePlatformTypes.SketchableListBox:
					return SilverlightTypes.SketchableListBoxType;
        case SketchablePlatformTypes.BreadCrumb:
          return SilverlightTypes.SketchableBreadCrumbType;
        case SketchablePlatformTypes.DataGrid:
          return SilverlightTypes.SketchableDataGridType;
        default:
          throw new ArgumentOutOfRangeException("platformType");
      }
    }

    /// <summary>
    /// Gets a type converter which can handle sketching markup for the
    /// submitted model item.
    /// </summary>
    /// <returns></returns>
    public override ISketchingMarkupConverter GetConverter(ModelItem modelItem)
    {
      if (modelItem.IsItemOfType(SilverlightTypes.TabControlType))
      {
        return new SLTabControlConverter();
      }

      if (modelItem.IsItemOfType(SilverlightTypes.ListBoxType))
      {
        return new SLListBoxConverter();
      }

      return new SketchableMarkupConverter();
    }



    /// <summary>
    /// Resolves all types that are supported by the library.
    /// </summary>
    /// <returns></returns>
    protected override IEnumerable<Type> GetSupportedTypes()
    {
			//currently not used
			throw new NotSupportedException("");
			//return new[]
			//         {
			//           SilverlightTypes.SketchableControlType,
			//           SilverlightTypes.TabControlType,
			//           SilverlightTypes.ListBoxType
			//         };
    }



  }
}
