﻿// Sketchables.NET - Design Time Support Libraries
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Gnu General Public License (GPL) v3
// Please see http://www.gnu.org/licenses/gpl.html for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System;
using System.Collections.Generic;
using System.Windows.Controls;
using Microsoft.Windows.Design.Model;
using Sketchables.Controls;
using Sketchables.Design;
using Sketchables.Design.Markup;

namespace Sketchables.WPF.Design
{
  /// <summary>
  /// Resolves types for the WPF library.
  /// </summary>
  internal class WpfTypeFactory : SketchableTypeFactory
  {
    private static readonly Type SketchableControlType = typeof (SketchableControl);

    private static readonly Type TabControlType = typeof (TabControl);

		private static readonly Type SketchableTabControlType = typeof(SketchableTabControl);

    private static readonly Type ListBoxType = typeof(ListBox);

		private static readonly Type SketchableListBoxType = typeof(SketchableListBox);

    private static readonly Type SketchableBreadCrumbType = typeof(SketchableBreadCrumb);

    private static readonly Type SketchableDataGridType = typeof(SketchableDataGrid);

    /// <summary>
    /// Returns the platform-specific type defined by the underlying enum.
    /// </summary>
    /// <returns></returns>
    public override Type GetPlatformType(SketchablePlatformTypes platformType)
    {
      switch (platformType)
      {
        case SketchablePlatformTypes.SketchableControl:
          return SketchableControlType;
        case SketchablePlatformTypes.TabControl:
          return TabControlType;
				case SketchablePlatformTypes.SketchableTabControl:
					return SketchableTabControlType;
        case SketchablePlatformTypes.ListBox:
          return ListBoxType;
				case SketchablePlatformTypes.SketchableListBox:
					return SketchableListBoxType;
        case SketchablePlatformTypes.BreadCrumb:
          return SketchableBreadCrumbType;
        case SketchablePlatformTypes.DataGrid:
          return SketchableDataGridType;
        default:
          throw new ArgumentOutOfRangeException("platformType");
      }
    }

    /// <summary>
    /// Gets a type converter which can handle sketching markup for the
    /// submitted model item.
    /// </summary>
    /// <returns></returns>
    public override ISketchingMarkupConverter GetConverter(ModelItem modelItem)
    {     
      if(modelItem.IsItemOfType(TabControlType))
      {
        return new WpfTabControlConverter();
      }

      if(modelItem.IsItemOfType(ListBoxType))
      {
        return new WpfListBoxConverter();
      }

      return new SketchableMarkupConverter();
    }


    /// <summary>
    /// Resolves all types that are supported by the library.
    /// </summary>
    /// <returns></returns>
    protected override IEnumerable<Type> GetSupportedTypes()
    {
			//currently not used
			throw new NotSupportedException("");
      //return new[] {SketchableControlType, TabControlType, ListBoxType};
    }
  }
}
