﻿// Sketchables.NET - Rapid SketchFlow Prototyping
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Microsoft Public License (Ms-PL).
// Please see http://go.microsoft.com/fwlink/?LinkID=131993 for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System.Collections.Generic;
using System.Linq;

namespace Sketchables
{
  /// <summary>
  /// An item that is part of a given sketch control, usually
  /// as a member in a list of similar items.
  /// </summary>
  public class SketchItem
  {
    /// <summary>
    /// The index of the item. Used for all ordered items.
    /// </summary>
    public int Index { get; set; }

    /// <summary>
    /// The item definition as entered, including directives.
    /// </summary>
    public string Value { get; set; }

    /// <summary>
    /// A cleaned up string that is displayed on screen.
    /// </summary>
    public string ContentMarkup { get; set; }

    private IEnumerable<Directive> directives = new Directive[0];

    /// <summary>
    /// Formatting or display directives. These are the things encapsulated
    /// in brackets, e.g. <c>[x]</c>. Note that the returned collection
    /// returns the directive values without brackets.
    /// </summary>
    public IEnumerable<Directive> Directives
    {
      get { return directives; }
      set { directives = value ?? new Directive[0]; }
    }

    /// <summary>
    /// Checks whether the <see cref="Directives"/> collection contains
    /// a given directive.
    /// </summary>
    /// <param name="directive"></param>
    /// <returns></returns>
    public bool HasDirective(string directive)
    {
      return Directives.Any(d => d.Name == directive);
    }


    /// <summary>
    /// Gets a directive with a given <see cref="Directive.Name"/>,
    /// if available.
    /// </summary>
    /// <param name="directive">The name part of the directive.</param>
    /// <returns>The first matching directive. Otherwise null.</returns>
    public Directive TryGetDirective(string directive)
    {
      return Directives.FirstOrDefault(d => d.Name == directive);
    }

  }
}
