﻿using System;
using System.Linq;
using System.Reflection;
using System.Windows;
using System.Windows.Resources;
using Microsoft.Expression.Prototyping.Data;

namespace Sketchables.Behaviors
{
  public static class ScreenUtil
  {
    /// <summary>
    /// Resolves SketchFlow navigation data through reflection.
    /// </summary>
    public static Serializer.Data LoadNavigationData()
    {
      //make sure the application has been loaded
      Application current = Application.Current;

      var runtimeAssembly = GetRuntimeAssembly();
      if(runtimeAssembly == null) return new Serializer.Data();

      const string typeName = "Microsoft.Expression.Prototyping.Services.PlayerContext";
      var type = runtimeAssembly.GetType(typeName, true);
      PropertyInfo pi = type.GetProperty("Instance", BindingFlags.Static | BindingFlags.Public);

      dynamic playerContext = pi.GetValue(null, new object[0]);
      return playerContext.RuntimeData ?? new Serializer.Data();
    }


    /// <summary>
    /// Resolves the expression runtime assembly.
    /// </summary>
    /// <returns></returns>
    private static Assembly GetRuntimeAssembly()
    {
#if SILVERLIGHT
      const string runtimeAssembly = "Microsoft.Expression.Prototyping.Runtime.dll";
      foreach (AssemblyPart part in Deployment.Current.Parts)
      {
        if (part.Source.Equals(runtimeAssembly))
        {
          StreamResourceInfo resourceStream = Application.GetResourceStream(new Uri(part.Source, UriKind.Relative));
          if (resourceStream != null)
          {
            Assembly assembly = new AssemblyPart().Load(resourceStream.Stream);
            if (assembly != null)
            {
              return assembly;
            }
          }
        }
      }
#else
      const string runtimeAssembly = "Microsoft.Expression.Prototyping.Runtime";
      var assemblies = AppDomain.CurrentDomain.GetAssemblies();
      return assemblies.FirstOrDefault(assembly => assembly.GetName().Name.Equals(runtimeAssembly));
#endif

      //default to null
      return null;
    }
  }
}
