﻿// Sketchables.NET - Rapid SketchFlow Prototyping
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Microsoft Public License (Ms-PL).
// Please see http://go.microsoft.com/fwlink/?LinkID=131993 for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System;
using System.Collections.Generic;
using System.Windows.Controls;

namespace Sketchables.Controls
{
  /// <summary>
  /// Encapsulates a simple view model for sketched data grids.
  /// </summary>
  public class DataGridViewModel : ViewModelBase
  {
    #region HeaderVisibility

    private DataGridHeadersVisibility headerVisibility = DataGridHeadersVisibility.Column;

    /// <summary>
    /// Defines whether column headers are visible or not.
    /// </summary>
    public DataGridHeadersVisibility HeaderVisibility
    {
      get { return headerVisibility; }
      set
      {
        headerVisibility = value;
        OnPropertyChanged(() => HeaderVisibility);
      }
    }

    #endregion

    #region Items

    private IEnumerable<RowSketchItem> rowItems;

    /// <summary>
    /// The items that provide the data to be displayed. One <see cref="RowSketchItem"/>
    /// represents a single grid line.
    /// </summary>
    public IEnumerable<RowSketchItem> RowItems
    {
      get { return rowItems; }
      set
      {
        rowItems = value;
        OnPropertyChanged(() => RowItems);
      }
    }

    #endregion

    #region SelectedItem

    /// <summary>
    /// An optional action that is invoked if the <see cref="SelectedItem"/>
    /// is changed.
    /// </summary>
    public Action<SketchItem> SelectedItemEventInvoker { get; set; }

    private RowSketchItem selectedItem;

    /// <summary>
    /// The currently selected item.
    /// </summary>
    public RowSketchItem SelectedItem
    {
      get { return selectedItem; }
      set
      {
        selectedItem = value;
        OnPropertyChanged(() => SelectedItem);

        if(value != null && SelectedItemEventInvoker != null)
        {
          SelectedItemEventInvoker(value);
        }
      }
    }

    #endregion

    #region HeaderRow

    private RowSketchItem headerRow;

    /// <summary>
    /// The column header row, if any.
    /// </summary>
    public RowSketchItem HeaderRow
    {
      get { return headerRow; }
      set
      {
        headerRow = value;
        OnPropertyChanged(() => HeaderRow);
      }
    }

    #endregion





    public void SetHeaderVisibility(bool isVisible)
    {
      HeaderVisibility = isVisible
                           ? DataGridHeadersVisibility.Column
                           : DataGridHeadersVisibility.None;
    }
  }
}
