﻿// Sketchables.NET - Rapid SketchFlow Prototyping
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Microsoft Public License (Ms-PL).
// Please see http://go.microsoft.com/fwlink/?LinkID=131993 for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System.Collections.Generic;
using System.Linq;

namespace Sketchables.Controls
{
  /// <summary>
  /// Represents a row in a matrix.
  /// </summary>
  public class RowSketchItem : SketchItem
  {
    /// <summary>
    /// The contains items.
    /// </summary>
    public List<SketchItem> Cells { get; set; }


    /// <summary>
    /// Parses the markup for a single row items, and populates
    /// the <see cref="Cells"/> collection.
    /// </summary>
    /// <param name="rowMarkup"></param>
    /// <param name="rowIndex"></param>
    /// <returns></returns>
    public static RowSketchItem Create(string rowMarkup, int rowIndex)
    {
      var rowItem = new RowSketchItem {Index = rowIndex};

      //rows don't have row directives, but regular directives for all cells
      //accordingly, the value is the markup
      rowItem.Value = rowItem.ContentMarkup = rowMarkup;

      //split directives
      rowItem.Cells = rowItem.ContentMarkup.SplitString()
        .Select((c, i) => new SketchItem().Init(c, i))
        .ToList();

      //cleanup content value
      rowItem.Cells.ForEach(si => si.ContentMarkup = si.ContentMarkup.TrimSingleSpace().Unescape());
      return rowItem;
    }

  }
}
