﻿// Sketchables.NET - Rapid SketchFlow Prototyping
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Microsoft Public License (Ms-PL).
// Please see http://go.microsoft.com/fwlink/?LinkID=131993 for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;

namespace Sketchables.Controls
{
  /// <summary>
  /// Renders a list of <see cref="ToggleButton"/> controls based on the
  /// contents of the <see cref="SketchableItemsControl.SketchItems"/>
  /// collection.
  /// </summary>
  public abstract  class ToggleButtonGroup : SketchableItemsControl
  {
    /// <summary>
    /// Invoked by the <see cref="SketchableControl.CreateRuntimeElementInternal"/>. Deriving classes
    /// should create their runtime content based on the <see cref="SketchableItemsControl.SketchItems"/>
    /// property.
    /// </summary>
    /// <returns>The runtime element to be displayed.</returns>
    protected override UIElement CreateRuntimeElementInternal()
    {
      bool isHorizontal = Content != null && !Content.Contains("\n");

      var elements = new List<FrameworkElement>();
      foreach (var sketchItem in SketchItems)
      {
        FrameworkElement element;
        if (sketchItem == null)
        {
          element = ControlBuilder.CreateTextBlock(" ");
        }
        else if (sketchItem.IsLabel())
        {
          element = ControlBuilder.CreateTextBlock(sketchItem.ContentMarkup);
        }
        else
        {
          var button = CreateToggleButtonWithAppliedStyle();
          button.IsChecked = sketchItem.IsSelected();
          button.IsEnabled = sketchItem.IsEnabled();
          button.Content = sketchItem.ContentMarkup;

          element = button;
        }

        elements.Add(element);
      }

      return ContentUtil.CreateGrid(elements, isHorizontal ? Orientation.Horizontal : Orientation.Vertical);
    }


    /// <summary>
    /// Creates the <see cref="ToggleButton"/> type to be rendered for each
    /// element in the <see cref="SketchableItemsControl.SketchItems"/> collection.
    /// </summary>
    /// <returns>A <see cref="ToggleButton"/> instance, e.g. a <see cref="CheckBox"/>.</returns>
    protected abstract ToggleButton CreateToggleButtonWithAppliedStyle();
  }
}