// Sketchables.NET - Rapid SketchFlow Prototyping
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Microsoft Public License (Ms-PL).
// Please see http://go.microsoft.com/fwlink/?LinkID=131993 for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System;
using System.Linq;
using System.Windows;
using System.Windows.Controls;

namespace Sketchables.Controls
{
  /// <summary>
  /// Renders a <see cref="ListBox"/> control based on the
  /// contents of the <see cref="SketchableItemsControl.SketchItems"/>
  /// collection.
  /// </summary>
  public class SketchableListBox : SketchableItemsControl
  {
    /// <summary>
    /// Invoked by <see cref="SketchableControl.RefreshRuntimeElement"/>.
    /// Deriving classes should create their runtime content based on the
    /// <see cref="SketchableItemsControl.SketchItems"/> property.
    /// </summary>
    /// <returns>The runtime element to be displayed.</returns>
    protected override UIElement CreateRuntimeElementInternal()
    {
    	var listBox = (ListBox) RuntimeElement;

			if (listBox == null)
			{
				//create one instance and keep it
				listBox = new ListBox().WithStyle(SketchStyleNames.ListBox);
				listBox.SelectionChanged += OnSelectionChanged;
				RuntimeElement = listBox;
			}
			else
			{
				listBox.Items.Clear();	
			}

			//TODO handle empty entries
      var items = SketchItems.Select(i => new ListBoxItem
                                     {
                                       Content = i.ContentMarkup,
                                       IsSelected = i.IsSelected(),
                                       IsEnabled = i.IsEnabled(),
																			 Tag = i
                                     }.WithStyle(SketchStyleNames.ListBoxItem));

      //allow multiple selections if configured accordingly
      if(SketchItems.Count(i => i.IsSelected()) > 1)
      {
				listBox.SelectionMode = SelectionMode.Multiple;
      }

      foreach (var listBoxItem in items)
      {
				listBox.Items.Add(listBoxItem);
      }

			return listBox;
    }



  	private void OnSelectionChanged(object sender, SelectionChangedEventArgs e)
  	{
			if (e.AddedItems.Count == 0) return;

  		var item = ((ListBoxItem) e.AddedItems[0]).Tag;
  		RaiseItemChanged((SketchItem) item);
  	}
  }
}
