﻿// Sketchables.NET - Rapid SketchFlow Prototyping
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Microsoft Public License (Ms-PL).
// Please see http://go.microsoft.com/fwlink/?LinkID=131993 for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System.Collections.Generic;
using System.Linq;
using System.Windows;
using System.Windows.Controls;

namespace Sketchables.Controls
{
  /// <summary>
  /// Renders the contents of the <see cref="SketchableItemsControl.SketchItems"/>
  /// collection as a horizontal list of hyperlinks.
  /// </summary>
  public partial class SketchableBreadCrumb : SketchableItemsControl
  {
    private List<FrameworkElement> elements;
    private Grid parentGrid;

    /// <summary>
    /// This abstract builder method is responsible for creating the
    /// <see cref="SketchableControl.RuntimeElement"/> that is displayed
    /// at runtime and represents the sketched item. This method is being
    /// invoked by the <see cref="RuntimeCompositionSketchControl.RefreshRuntimeElement"/>
    /// method. Do not invoke it in order to have the UI updated.
    /// </summary>
    /// <returns>The runtime element to be displayed.</returns>
    protected override UIElement CreateRuntimeElementInternal()
    {
      //discard old elememts
      UnregisterLinkEventListeners(elements, parentGrid);


      elements = new List<FrameworkElement>();

      var items = SketchItems.ToArray();
      for (int index = 0; index < items.Length; index++)
      {
        var item = items[index];

        //invoke builder method in partial class
        elements.Add(item.CreateHyperlink());
        
        if(index < items.Length-1)
        {
          var label = ControlBuilder.CreateTextBlock(">");
          label.HorizontalAlignment = HorizontalAlignment.Center;
          elements.Add(label);
        }
      }

      //create grid
      parentGrid = ContentUtil.CreateGrid(elements, Orientation.Horizontal);

      //register event listeners
      RegisterLinkEventListeners(elements, parentGrid);


      //adjust column definitions in order not to render elements star sized
      for (int i = 0; i < elements.Count; i++)
      {
        parentGrid.ColumnDefinitions[i].Width = new GridLength(0, GridUnitType.Auto);
        parentGrid.ColumnDefinitions[i].MinWidth = 20;
      }

      return parentGrid;
    }

  }


}