﻿// Sketchables.NET - Rapid SketchFlow Prototyping
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Microsoft Public License (Ms-PL).
// Please see http://go.microsoft.com/fwlink/?LinkID=131993 for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System.Windows;

namespace Sketchables.Controls
{
  /// <summary>
  /// Common base class for controls that recreate their
  /// <see cref="SketchableControl.RuntimeElement"/> with
  /// every refresh.
  /// </summary>
  public abstract class RuntimeCompositionSketchControl : SketchableControl
  {
    /// <summary>
    /// Swaps out the current <see cref="SketchableControl.RuntimeElement"/> by the instance
    /// created in <see cref="CreateRuntimeElementInternal"/>.
    /// </summary>
    public override void RefreshRuntimeElement()
    {
      RuntimeElement = CreateRuntimeElementInternal();
    }


    /// <summary>
    /// This abstract builder method is responsible for creating the
    /// <see cref="SketchableControl.RuntimeElement"/> that is displayed
    /// at runtime and represents the sketched item. This method is being
    /// invoked by the <see cref="RefreshRuntimeElement"/> method. Do not invoke
    /// it in order to have the UI updated.
    /// </summary>
    /// <returns>The runtime element to be displayed.</returns>
    protected abstract UIElement CreateRuntimeElementInternal();
  }
}
