﻿// Sketchables.NET - Rapid SketchFlow Prototyping
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Microsoft Public License (Ms-PL).
// Please see http://go.microsoft.com/fwlink/?LinkID=131993 for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System.Collections.ObjectModel;
using System.Collections.Specialized;
using System.Windows;
using System.Windows.Markup;

namespace Sketchables.Controls
{
  
  [ContentProperty("Children")]
  public abstract class SketchableContainerControl : SketchableItemsControl
  {

    #region SketchIndex

    /// <summary>
    /// SketchIndex Attached Dependency Property
    /// </summary>
    public static readonly DependencyProperty SketchIndexProperty =
        DependencyProperty.RegisterAttached("SketchIndex", typeof(int), typeof(SketchableContainerControl),
            new PropertyMetadata(-1));

    /// <summary>
    /// Gets the SketchIndex property.  This dependency property 
    /// indicates the index of a related item in the sketching hiearchy.
    /// </summary>
    public static int GetSketchIndex(DependencyObject d)
    {
      return (int)d.GetValue(SketchIndexProperty);
    }

    /// <summary>
    /// Sets the SketchIndex property.  This dependency property 
    /// indicates the index of a related item in the sketching hiearchy.
    /// </summary>
    public static void SetSketchIndex(DependencyObject d, int value)
    {
      d.SetValue(SketchIndexProperty, value);
    }

    #endregion


    public ObservableCollection<UIElement> Children { get; private set; }


    protected SketchableContainerControl()
    {
      Children = new ObservableCollection<UIElement>();
      Children.CollectionChanged += OnChildrenCollectionChanged;
    }


    /// <summary>
    /// Triggers an update if the <see cref="Children"/> collection changed.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void OnChildrenCollectionChanged(object sender, NotifyCollectionChangedEventArgs e)
    {
      RefreshRuntimeElement();
    }
  }
}
