﻿// Sketchables.NET - Rapid SketchFlow Prototyping
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Microsoft Public License (Ms-PL).
// Please see http://go.microsoft.com/fwlink/?LinkID=131993 for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Markup;

namespace Sketchables.Controls
{
  [ContentProperty("Child")]
  public class SketchableTabControl : SketchableItemsControl
  {
    protected TabControl Tabs { get; private set; }

    public SketchableTabControl()
    {
      Tabs = new TabControl().WithStyle(SketchStyleNames.TabControl);
      Tabs.SelectionChanged += OnTabSelectionChanged;
    }

    private void OnTabSelectionChanged(object sender, SelectionChangedEventArgs e)
    {

    }


    #region Child

    /// <summary>
    /// Child Dependency Property
    /// </summary>
    public static readonly DependencyProperty ChildProperty =
        DependencyProperty.Register("Child", typeof(UIElement), typeof(SketchableTabControl),
            new PropertyMetadata(null, OnChildChanged));

    private static void OnChildChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
    {
      ((SketchableTabControl)d).RefreshRuntimeElement();
    }

    /// <summary>
    /// Gets or sets the Child property.  This dependency property 
    /// indicates ....
    /// </summary>
    public UIElement Child
    {
      get { return (UIElement)GetValue(ChildProperty); }
      set { SetValue(ChildProperty, value); }
    }

    #endregion


    /// <summary>
    /// Invoked by the <see cref="SketchableControl.CreateRuntimeElementInternal"/>. Deriving classes
    /// should create their runtime content based on the <see cref="SketchableItemsControl.SketchItems"/>
    /// property.
    /// </summary>
    /// <returns>The runtime element to be displayed.</returns>
    protected override UIElement CreateRuntimeElementInternal()
    {
      if (SketchItems == null) return null;

      var tabs = RuntimeElement as TabControl;
      RuntimeElement = null;
      //disconnect items on existing tab control
      if (tabs != null)
      {
        foreach (TabItem tabItem in tabs.Items)
        {
          tabItem.Content = null;
        }
      }

      var tabItems = SketchItems.Where(si => si != null)
        .Select(s => new TabItem
                       {
                         Header = s.ContentMarkup,
                         IsEnabled = s.IsEnabled(),
                         IsSelected = s.IsSelected(),
                         Content = s.IsSelected() ? Child : null
                       }
                       .WithStyle(SketchStyleNames.TabItem))
                       .ToList();


      tabs = new TabControl().WithStyle(SketchStyleNames.TabControl);
      tabItems.ForEach(item => tabs.Items.Add(item));

      return tabs;
    }



    
  }
}
