﻿// Sketchables.NET - Rapid SketchFlow Prototyping
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Microsoft Public License (Ms-PL).
// Please see http://go.microsoft.com/fwlink/?LinkID=131993 for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System.Collections.Generic;
using System.Linq;
using System.Windows;
using System.Windows.Controls;



namespace Sketchables
{
  public static class ContentUtil
  {

    /// <summary>
    /// Arranges the submitted items in a uniform grid.
    /// </summary>
    /// <param name="elements"></param>
    /// <param name="orientation"></param>
    /// <returns></returns>
    public static Grid CreateGrid(IEnumerable<FrameworkElement> elements, Orientation orientation)
    {
      var grid = new Grid();

      var items = elements.ToArray();
      for (int i = 0; i < items.Length; i++)
      {
        FrameworkElement item = items[i];
        grid.Children.Add(item);

        if (orientation == Orientation.Horizontal)
        {
          grid.ColumnDefinitions.Add(new ColumnDefinition());
          Grid.SetColumn(item, i);
        }
        else
        {
          grid.RowDefinitions.Add(new RowDefinition());
          Grid.SetRow(item, i);
        }
      }


      return grid;
    }



    /// <summary>
    /// Prepares a grid control with star sized rows and columns.
    /// </summary>
    public static Grid PrepareGrid(int columnCount, int rowCount)
    {
      var grid = new Grid();
      for (int i = 0; i < columnCount; i++)
      {
        grid.ColumnDefinitions.Add(new ColumnDefinition());
      }

      for (int i = 0; i < rowCount; i++)
      {
        grid.RowDefinitions.Add(new RowDefinition());
      }

      return grid;
    }



    /// <summary>
    /// Resolves a style for a given element. In WPF projects, this will be a dynamic reference,
    /// in Silverlight, this helper method tries to find and assign the style directly.
    /// </summary>
    /// <typeparam name="T"></typeparam>
    /// <param name="element"></param>
    /// <param name="styleName"></param>
    /// <returns></returns>
    public static T WithStyle<T>(this T element, string styleName) where T:FrameworkElement
    {
#if SILVERLIGHT
      element.Style = (Style) element.TryFindResource(styleName);      
#else
      element.SetResourceReference(FrameworkElement.StyleProperty, styleName);
#endif

      return element;
    }
  }
}