﻿// Sketchables.NET - Rapid SketchFlow Prototyping
// (c) Copyright 2010 Philipp Sumi
// Contact and Information: http://www.hardcodet.net
//
// This source is subject to the Microsoft Public License (Ms-PL).
// Please see http://go.microsoft.com/fwlink/?LinkID=131993 for details.
// All other rights reserved.
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
// OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
//
// THIS COPYRIGHT NOTICE MAY NOT BE REMOVED FROM THIS FILE


using System;
using System.Diagnostics;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using Microsoft.Expression.Prototyping.SketchControls;

namespace Sketchables.Controls
{
  public static partial class ControlBuilder
  {
    private static GridLengthConverter gridLengthConverter = new GridLengthConverter();

    /// <summary>
    /// Creates a <see cref="Hyperlink"/> with the submitted text,
    /// wrapped into a <see cref="TextBlock"/>.
    /// </summary>
    /// <param name="item">The item that represents the control
    /// to be built.</param>
    /// <param name="linkText">Displayed link.</param>
    /// <returns>Built control.</returns>
    public static FrameworkElement CreateHyperlink(this SketchItem item, string linkText)
    {
      var tb = CreateTextBlock(null);

      //set the uri in order to have the navigation event being fired,
      //the tag is used in the event listener
      var link = new Hyperlink
                   {
                     NavigateUri = new Uri("sketchables://item?index=" + item.Index),
                     Tag = item
                   };

      

      link.Inlines.Add(new Run {Text = linkText});
      tb.Inlines.Add(link);

      link.Foreground = item.IsSelected() ? GetActiveHyperlinkBrush() : GetHyperlinkBrush();

      if (!item.IsEnabled() || item.IsSelected())
      {
        //render disabled / selected links as normal text
        tb.IsEnabled = false;
      }

      return tb;
    }


    /// <summary>
    /// Creates a rectangle with a sketched look and the specified stroke width.
    /// </summary>
    /// <param name="strokeWidth">The width of the sketched rectangle stroke. Defaults
    /// to 1.</param>
    public static FrameworkElement CreateSketchRectangle(double strokeWidth = 1)
    {
      return new  SketchRectangleUC { StrokeWidth = strokeWidth };
    }


    /// <summary>
    /// Parser function that converts a string into a <see cref="GridLength"/>.
    /// </summary>
    /// <param name="lengthString"></param>
    /// <returns>Converted value. If the value cannot be converted, a value of
    /// <see cref="GridLength.Auto"/> is returned.</returns>
    public static GridLength ParseGridLength(string lengthString)
    {
      try
      {
        if (String.IsNullOrWhiteSpace(lengthString)) return GridLength.Auto;
        return (GridLength) gridLengthConverter.ConvertFromInvariantString(lengthString);
      }
      catch (Exception e)
      {
        var msg = String.Format("Couldn't convert string {0} into [GridLength]", lengthString);
        Debug.WriteLine(msg);
        return GridLength.Auto;
      }
    }
  }
}